<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Kablosuz Aç</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Kablosuz kapat</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Büyük Harf aç</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Büyük Harf kapat</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Sayısal Klavyeyi aç</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Sayısal Klavye kapat</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Dokunmatik Yüzey aç</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Dokunmatik Yüzey kapat</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Dokunmatik yüzeyi açma</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn açma</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Uçak Kipi  açık</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Uçak Kipi kapalı</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Dengeli Güç</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Güç tasarrufu</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Yüksek performans</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Pencere etkisi etkinleştirildi</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Pencere etkisi devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Pencere etkileri etkinleştirilemedi</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Mikrofon kapalı</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Mikrofon açık</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation>Kamera açık</translation>
    </message>
    <message>
        <source>Camera off</source>
        <translation>Kamera kapalı</translation>
    </message>
</context>
</TS>